**Example 1: 保存优化模型**



Input: 

```
tccli tione CreateOptimizedModel --cli-unfold-argument  \
    --ModelAccTaskId acc-50rjzj2xtest
```

Output: 
```
{
    "Response": {
        "ModelVersionId": "mv-v1-660879334503305217",
        "RequestId": "ced11c16-fd5a-4f12-8a0b-17c7f0b14659",
        "ModelId": "m-660879334503305216"
    }
}
```

